==> tora_2.0.0.orig.tar.gz: tora-2.0.0/src/toresultschema.cpp <==

/* BEGIN_COMMON_COPYRIGHT_HEADER
 *
 * TOra - An Oracle Toolkit for DBA's and developers
 * 
 * Shared/mixed copyright is held throughout files in this product
 * 
 * Portions Copyright (C) 2000-2001 Underscore AB
 * Portions Copyright (C) 2003-2005 Quest Software, Inc.
 * Portions Copyright (C) 2004-2008 Numerous Other Contributors
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation;  only version 2 of
 * the License is valid for this program.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 *      As a special exception, you have permission to link this program
 *      with the Oracle Client libraries and distribute executables, as long
 *      as you follow the requirements of the GNU GPL in regard to all of the
 *      software in the executable aside from Oracle client libraries.
 * 
 *      Specifically you are not permitted to link this program with the
 *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
 *      And you are not permitted to distribute binaries compiled against
 *      these libraries. 
 * 
 *      You may link this product with any GPL'd Qt library.
 * 
 * All trademarks belong to their respective owners.
 *
 * END_COMMON_COPYRIGHT_HEADER */

#include "utils.h"
#include "toresultschema.h"
#include "toconnection.h"

#include <QSettings>


toResultSchema::toResultSchema(toConnection &conn,
                               QWidget *parent,
                               const char *name)
    : toResultCombo(parent, name)
{
    setSQL(toSQL::sql(toSQL::TOSQL_USERLIST));

    ConnectionKey =
        conn.provider() + "-" +
        conn.host() + "-" +
        conn.database();

    QString sel = conn.schema();

    if(sel.isEmpty())
    {
        QSettings s;
        sel = s.value("schema/" + ConnectionKey).toString();
    }

    if(sel.isEmpty())
    {
        if (toIsMySQL(conn))
            sel = conn.database();
        else if (toIsOracle(conn) || toIsSapDB(conn))
            sel = conn.user().toUpper();
        else
            sel = conn.user();
    }

    conn.setSchema(sel);
    setSelected(sel);
    connect(this,
            SIGNAL(currentIndexChanged(const QString &)),
            this,
            SLOT(updateLastSchema(const QString &)));

    setFocusPolicy(Qt::NoFocus);
}


#define CHANGE_CURRENT_SCHEMA QString("ALTER SESSION SET CURRENT_SCHEMA = %1")
#define CHANGE_CURRENT_SCHEMA_PG QString("SET search_path TO %1,\"$user\",public")

void toResultSchema::update() {
    update(toResultCombo::currentText());
}


void toResultSchema::update(const QString &schema) {
    if(schema.isEmpty())
        return;

    try {
        toConnection &conn = connection();

        if (toIsOracle(conn)) {
            /* remove current schema initstring */
            conn.delInit(CHANGE_CURRENT_SCHEMA.arg(conn.user()));

            /* set the new one with selected schema */
            QString sql = CHANGE_CURRENT_SCHEMA.arg(schema);
            conn.allExecute(sql);

            conn.addInit(sql);
        }
        else if (toIsMySQL(conn)) {
            conn.allExecute(QString("USE `%1`").arg(schema));
            conn.setDatabase(schema);
        }
        else if (toIsPostgreSQL(conn))
            conn.allExecute(CHANGE_CURRENT_SCHEMA_PG.arg(schema));
        else
            throw QString("No support for changing schema for this database");

        conn.setSchema(schema);
    }
    TOCATCH;
}


void toResultSchema::updateLastSchema(const QString &schema) {
    QSettings s;
    s.setValue("schema/" + ConnectionKey, schema);
}

==> tora_2.1.2.orig.tar.gz: tora-2.1.2/src/toresultschema.cpp <==

/* BEGIN_COMMON_COPYRIGHT_HEADER
 *
 * TOra - An Oracle Toolkit for DBA's and developers
 * 
 * Shared/mixed copyright is held throughout files in this product
 * 
 * Portions Copyright (C) 2000-2001 Underscore AB
 * Portions Copyright (C) 2003-2005 Quest Software, Inc.
 * Portions Copyright (C) 2004-2009 Numerous Other Contributors
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation;  only version 2 of
 * the License is valid for this program.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 *      As a special exception, you have permission to link this program
 *      with the Oracle Client libraries and distribute executables, as long
 *      as you follow the requirements of the GNU GPL in regard to all of the
 *      software in the executable aside from Oracle client libraries.
 * 
 *      Specifically you are not permitted to link this program with the
 *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
 *      And you are not permitted to distribute binaries compiled against
 *      these libraries. 
 * 
 *      You may link this product with any GPL'd Qt library.
 * 
 * All trademarks belong to their respective owners.
 *
 * END_COMMON_COPYRIGHT_HEADER */

#include "utils.h"
#include "toresultschema.h"
#include "toconnection.h"

#include <QSettings>


toResultSchema::toResultSchema(toConnection &conn,
                               QWidget *parent,
                               const char *name)
    : toResultCombo(parent, name)
{
    setSQL(toSQL::sql(toSQL::TOSQL_USERLIST));

    ConnectionKey =
        conn.provider() + "-" +
        conn.host() + "-" +
        conn.database();

    QString sel = conn.schema();

    if(sel.isEmpty())
    {
        QSettings s;
        sel = s.value("schema/" + ConnectionKey).toString();
    }

    if(sel.isEmpty())
    {
        if (toIsMySQL(conn))
            sel = conn.database();
        else
            sel = conn.user();
    }

    // Oracle usernames are always in upper case
    if (toIsOracle(conn) || toIsSapDB(conn)) sel = sel.toUpper();

    conn.setSchema(sel);
    setSelected(sel);
    connect(this,
            SIGNAL(currentIndexChanged(const QString &)),
            this,
            SLOT(updateLastSchema(const QString &)));

    setFocusPolicy(Qt::NoFocus);
}


#define CHANGE_CURRENT_SCHEMA QString("ALTER SESSION SET CURRENT_SCHEMA = \"%1\"")
#define CHANGE_CURRENT_SCHEMA_PG QString("SET search_path TO %1,\"$user\",public")

void toResultSchema::update() {
    update(toResultCombo::currentText());
}


void toResultSchema::update(const QString &schema) {
    if(schema.isEmpty())
        return;

    try {
        toConnection &conn = connection();

        if (toIsOracle(conn)) {
            /* remove current schema initstring */
            conn.delInit(CHANGE_CURRENT_SCHEMA.arg(conn.user()));

            /* set the new one with selected schema */
            QString sql = CHANGE_CURRENT_SCHEMA.arg(schema);
            conn.allExecute(sql);

            conn.addInit(sql);
        }
        else if (toIsMySQL(conn)) {
            conn.allExecute(QString("USE `%1`").arg(schema));
            conn.setDatabase(schema);
        }
        else if (toIsPostgreSQL(conn))
            conn.allExecute(CHANGE_CURRENT_SCHEMA_PG.arg(schema));
        else
            throw QString("No support for changing schema for this database");

        conn.setSchema(schema);
    }
    TOCATCH;
}


void toResultSchema::updateLastSchema(const QString &schema) {
    QSettings s;
    s.setValue("schema/" + ConnectionKey, schema);
}
